pdemenu: Interactive menu to set the options for the npde() function

View source: R/main.R

pdemenuR Documentation

Interactive menu to set the options for the npde() function

Description

Interactive menu to set the options for the npde() function

Usage

pdemenu()

Value

A list with the information needed to compute the pd/npde

Author(s)

Emmanuelle Comets <emmanuelle.comets@bichat.inserm.fr>

References

K. Brendel, E. Comets, C. Laffont, C. Laveille, and F. Mentre. Metrics for external model evaluation with an application to the population pharmacokinetics of gliclazide. Pharmaceutical Research, 23:2036–49, 2006.

See Also

npdeGraphs, gofTest


LAPKB/npde documentation built on Oct. 19, 2022, 2:10 p.m.